@@ -139,7 +139,6 @@
 #' @importFrom reshape2 melt
 #' @importFrom future plan future value
 #' @importFrom future.apply future_lapply
-#' @importFrom pscl zeroinfl
 #' @importFrom aods3 wald.test
 #'
 #' @export
@@ -163,6 +162,12 @@ gwqsrs <- function(formula, data, na.action, weights, mix_name, stratified, vali
   if(!any(grepl("wqs", rownames(attr(terms(formula), "factors"))))) stop("'formula' must contain 'wqs' term: e.g. y ~ wqs + ...")
 
   if(zero_infl){
+    if(!("pscl" %in% (.packages()))) stop("If you are willing to use zero-inflated WQS regression
+then you need to install the pscl package from GitHub
+using the following commands:\n
+install.packages(\"devtools\") ## if not already installed
+library(devtools)
+install_github(\"atahk/pscl\")")
     zilink <- make.link(match.arg(zilink))
     ff = formula
     if(length(formula[[3]]) > 1 && identical(formula[[3]][[1]], as.name("|")))
@@ -239,7 +244,7 @@ gwqsrs <- function(formula, data, na.action, weights, mix_name, stratified, vali
           f2 <- gWQS:::remove_terms(as.formula(paste0(ff[[2]], " ~ ", deparse(ff[[3]][[3]]))), "wqs")
           formula_wo_wqs <- as.formula(paste0(deparse(f1), " | ", f2[[3]]))
         }
-        fit <- zeroinfl(formula_wo_wqs, dtf[rindex$iv,], dist = family$family, link = zilink$name)
+        fit <- pscl::zeroinfl(formula_wo_wqs, dtf[rindex$iv,], dist = family$family, link = zilink$name)
       }
       else{
         if(family$family == "negbin") fit = glm.nb(formula_wo_wqs, dtf[rindex$iv,])
@@ -255,7 +260,7 @@ gwqsrs <- function(formula, data, na.action, weights, mix_name, stratified, vali
   else df_pred = NULL
 
   # Plots
-  data_plot <- data.frame(mix_name, mean_weight)
+  data_plot <- data.frame(mix_name, mean_weight, stringsAsFactors = TRUE)
 
   if(family$family == "multinomial"){
     Y <- model.response(model.frame(formula, dtf[rindex$iv,]), "any")
@@ -266,10 +271,12 @@ gwqsrs <- function(formula, data, na.action, weights, mix_name, stratified, vali
     y_adj_wqs_df = do.call("rbind", lapply(strata_names, function(i){
       if(n_levels > 3) data.frame(level = i,
                                   y = Y[rowSums(Y[, -which(colnames(Y)==i)]) == 0, i],
-                                  wqs = wqs_model$wqs[rowSums(Y[, -which(colnames(wqs_model$wqs)==i)]) == 0, i])
+                                  wqs = wqs_model$wqs[rowSums(Y[, -which(colnames(wqs_model$wqs)==i)]) == 0, i],
+                                  stringsAsFactors = TRUE)
       else data.frame(level = i,
                       y = Y[Y[, -which(colnames(Y)==i)] == 0, i],
-                      wqs = wqs_model$wqs[Y[, -which(colnames(wqs_model$wqs)==i)] == 0, i])
+                      wqs = wqs_model$wqs[Y[, -which(colnames(wqs_model$wqs)==i)] == 0, i],
+                      stringsAsFactors = TRUE)
     }))
   }
   else{
